﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;

namespace Infragistics.Windows.Extensions
{
	/// <summary>
	/// Event arguments for an event that passes along the event arguments from a different event.
	/// </summary>
	/// <typeparam name="T">A RoutedEventArgs derived type that represents the original/source event's arguments</typeparam>
	public class ProxyEventArgs<T> : RoutedEventArgs
		where T : RoutedEventArgs
	{
		#region Member Variables

		private T _args;

		#endregion //Member Variables

		#region Constructor
		/// <summary>
		/// Initializes a new <see cref="ProxyEventArgs&lt;T&gt;"/>
		/// </summary>
		/// <param name="args">The event arguments for the source event</param>
		public ProxyEventArgs(T args)
		{
			_args = args;
		}
		#endregion //Constructor

		#region Properties
		/// <summary>
		/// The event arguments for the source event.
		/// </summary>
		public T OriginalEventArgs
		{
			get { return _args; }
		}
		#endregion //Properties
	}
}
